@@ -340,7 +340,15 @@ func (r *userRepository) Delete(id string) error {
 	if errors.Is(err, model.ErrNotFound) {
 		return rest.ErrNotFound
 	}
-	return err
+	if err != nil {
+		return err
+	}
+
+	// Clean up orphaned plugin references for the deleted user
+	if err := cleanupPluginUserReferences(r.db, id); err != nil {
+		log.Error(r.ctx, "Failed to cleanup plugin user references", "userID", id, err)
+	}
+	return nil
 }
 
 func keyTo32Bytes(input string) []byte {
